@@ -15,7 +15,7 @@ from http import HTTPStatus
 from functools import partial
 
 
-__version__ = '1.0.1'
+__version__ = '1.1.0'
 
 
 if not (token := os.getenv('GITLAB_TOKEN')):
@@ -106,17 +106,17 @@ def validateCiConfig(baseUrl: str, configFile: str, silent: bool) -> int:
 if __name__ in ('gitlabci_lint.validate', '__main__'):
     parser = argparse.ArgumentParser(
         description=__doc__,
-        formatter_class=argparse.ArgumentDefaultsHelpFormatter
+        formatter_class=argparse.RawDescriptionHelpFormatter
+    )
+
+    parser.add_argument(
+        '-c', '--config', action='append',
+        help='CI Config files to check. (default: .gitlab-ci.yml)'
     )
 
     parser.add_argument(
         '-b', '-B', '--base_url', nargs='?', default='https://gitlab.com/',
-        help='Base GitLab URL.'
-    )
-
-    parser.add_argument(
-        '-c', '-C', '--config', nargs='?', default='.gitlab-ci.yml',
-        help='CI Config file to check.'
+        help='Base GitLab URL. (default: https://gitlab.com/)'
     )
 
     parser.add_argument(
@@ -126,17 +126,22 @@ if __name__ in ('gitlabci_lint.validate', '__main__'):
 
     parser.add_argument(
         '-q', '-Q', '--quiet', action='store_true', default=False,
-        help='Silently fail and pass, without output, unless improperly configured.'
+        help='Silently fail and pass, without output, unless improperly configured. '
+             '(default: False)'
     )
 
     args = parser.parse_args()
 
     base_url = args.base_url
-    config_file = args.config
+    config_files = args.config
+    if not config_files:
+        # Set default, since there's a bug in argparse that I can't seem to overcome with specifying
+        # multiple flags and defaults.
+        config_files = ['.gitlab-ci.yml']
     silence = args.quiet
 
-    if (exitCode := validateCiConfig(base_url, config_file, silence)) == os.EX_OK:
-        # Optionally could print message.
-        pass
+    for config in config_files:
+        if (exitCode := validateCiConfig(base_url, config, silence)) != os.EX_OK:
+            sys.exit(exitCode)
 
-    sys.exit(exitCode)
+    sys.exit(os.EX_OK)
